@@ -1,19 +1,30 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-table-model.c: a simple table model implementation that uses function
- * pointers to simplify the creation of new, exotic and colorful tables in
- * no time.
+ * e-table-simple.c
+ * Copyright 2000, 2001, Ximian, Inc.
  *
- * Author:
- *   Miguel de Icaza (miguel@gnu.org)
+ * Authors:
+ *   Chris Lahey <clahey@ximian.com>
+ *   Miguel de Icaza <miguel.ximian.com>
  *
- * (C) 1999, 2000 Ximian, Inc.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
 
 #include <config.h>
 #include "e-table-simple.h"
-
-#define PARENT_TYPE e_table_model_get_type ()
+#include "gal/util/e-util.h"
 
 static int
 simple_column_count (ETableModel *etm)
@@ -154,7 +165,7 @@ simple_value_to_string (ETableModel *etm, int col, const void *value)
 }
 
 static void
-e_table_simple_class_init (GtkObjectClass *object_class)
+e_table_simple_class_init (GObjectClass *object_class)
 {
 	ETableModelClass *model_class = (ETableModelClass *) object_class;
 
@@ -176,28 +187,7 @@ e_table_simple_class_init (GtkObjectClass *object_class)
 	model_class->value_to_string   = simple_value_to_string;
 }
 
-GtkType
-e_table_simple_get_type (void)
-{
-	static GtkType type = 0;
-
-	if (!type){
-		GtkTypeInfo info = {
-			"ETableSimple",
-			sizeof (ETableSimple),
-			sizeof (ETableSimpleClass),
-			(GtkClassInitFunc) e_table_simple_class_init,
-			(GtkObjectInitFunc) NULL,
-			NULL, /* reserved 1 */
-			NULL, /* reserved 2 */
-			(GtkClassInitFunc) NULL
-		};
-
-		type = gtk_type_unique (PARENT_TYPE, &info);
-	}
-
-	return type;
-}
+E_MAKE_TYPE(e_table_simple, "ETableSimple", ETableSimple, e_table_simple_class_init, NULL, E_TABLE_MODEL_TYPE)
 
 /**
  * e_table_simple_new:
@@ -245,9 +235,7 @@ e_table_simple_new  (ETableSimpleColumnCountFn      col_count,
 		     ETableSimpleValueToStringFn    value_to_string,
 		     void                          *data)
 {
-	ETableSimple *et;
-
-	et                    = gtk_type_new (e_table_simple_get_type ());
+	ETableSimple *et = g_object_new (E_TABLE_SIMPLE_TYPE, NULL);
 
 	et->col_count         = col_count;
 	et->row_count         = row_count;
@@ -269,3 +257,33 @@ e_table_simple_new  (ETableSimpleColumnCountFn      col_count,
 
 	return (ETableModel *) et;
 }
+
+void *
+e_table_simple_string_duplicate_value (ETableModel *etm, int col, const void *val, void *data)
+{
+	return g_strdup (val);
+}
+
+void
+e_table_simple_string_free_value (ETableModel *etm, int col, void *val, void *data)
+{
+	g_free (val);
+}
+
+void *
+e_table_simple_string_initialize_value (ETableModel *etm, int col, void *data)
+{
+	return g_strdup ("");
+}
+
+gboolean
+e_table_simple_string_value_is_empty (ETableModel *etm, int col, const void *val, void *data)
+{
+	return !(val && * (char *) val);
+}
+
+char *
+e_table_simple_string_value_to_string (ETableModel *etm, int col, const void *val, void *data)
+{
+	return g_strdup (val);
+}
