@@ -78,7 +78,7 @@
 
 static void e_icon_bar_class_init (EIconBarClass *class);
 static void e_icon_bar_init (EIconBar *icon_bar);
-static void e_icon_bar_destroy (GtkObject *object);
+static void e_icon_bar_dispose (GObject *object);
 static void e_icon_bar_size_allocate (GtkWidget *widget,
 				      GtkAllocation *allocation);
 static gint e_icon_bar_leave_notify_event (GtkWidget *widget,
@@ -143,70 +143,50 @@ enum
 
 static guint e_icon_bar_signals[LAST_SIGNAL] = {0};
 
+#define PARENT_TYPE E_CANVAS_TYPE
 static ECanvasClass *parent_class;
 
-
-GtkType
-e_icon_bar_get_type (void)
-{
-	static GtkType e_icon_bar_type = 0;
-
-	if (!e_icon_bar_type){
-		GtkTypeInfo e_icon_bar_info = {
-			"EIconBar",
-			sizeof (EIconBar),
-			sizeof (EIconBarClass),
-			(GtkClassInitFunc) e_icon_bar_class_init,
-			(GtkObjectInitFunc) e_icon_bar_init,
-			NULL, /* reserved 1 */
-			NULL, /* reserved 2 */
-			(GtkClassInitFunc) NULL
-		};
-
-		parent_class = gtk_type_class (e_canvas_get_type ());
-		e_icon_bar_type = gtk_type_unique (e_canvas_get_type (),
-						   &e_icon_bar_info);
-	}
-
-	return e_icon_bar_type;
-}
-
+E_MAKE_TYPE (e_icon_bar,
+	     "EIconBar",
+	     EIconBar,
+	     e_icon_bar_class_init,
+	     e_icon_bar_init,
+	     PARENT_TYPE)
 
 static void
 e_icon_bar_class_init (EIconBarClass *class)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	ECanvasClass *ecanvas_class;
 
-	object_class = (GtkObjectClass *) class;
+	object_class = (GObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 	ecanvas_class = E_CANVAS_CLASS( class );
 
-	e_icon_bar_signals[ITEM_SELECTED] =
-		gtk_signal_new ("item_selected",
-				GTK_RUN_LAST | GTK_RUN_ACTION,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (EIconBarClass,
-						   selected_item),
-				e_marshal_NONE__BOXED_INT,
-				GTK_TYPE_NONE, 2, GDK_TYPE_EVENT,
-				GTK_TYPE_INT);
-	e_icon_bar_signals[ITEM_DRAGGED] =
-		gtk_signal_new ("item_dragged",
-				GTK_RUN_LAST | GTK_RUN_ACTION,
-				E_OBJECT_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (EIconBarClass,
-						   dragged_item),
-				e_marshal_NONE__BOXED_INT,
-				GTK_TYPE_NONE, 2, GDK_TYPE_EVENT,
-				GTK_TYPE_INT);
+	parent_class = g_type_class_ref (PARENT_TYPE);
 
-	E_OBJECT_CLASS_ADD_SIGNALS (object_class, e_icon_bar_signals,
-				      LAST_SIGNAL);
+	e_icon_bar_signals[ITEM_SELECTED] =
+		g_signal_new ("item_selected",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+			      G_STRUCT_OFFSET (EIconBarClass, selected_item),
+			      NULL, NULL,
+			      e_marshal_NONE__BOXED_INT,
+			      G_TYPE_NONE, 2, GDK_TYPE_EVENT,
+			      G_TYPE_INT);
+	e_icon_bar_signals[ITEM_DRAGGED] =
+		g_signal_new ("item_dragged",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+			      G_STRUCT_OFFSET (EIconBarClass, dragged_item),
+			      NULL, NULL,
+			      e_marshal_NONE__BOXED_INT,
+			      G_TYPE_NONE, 2, GDK_TYPE_EVENT,
+			      G_TYPE_INT);
 
 	/* Method override */
-	object_class->destroy		 = e_icon_bar_destroy;
+	object_class->dispose		 = e_icon_bar_dispose;
 
  	widget_class->size_allocate	 = e_icon_bar_size_allocate;
  	widget_class->leave_notify_event = e_icon_bar_leave_notify_event;
@@ -290,14 +270,14 @@ e_icon_bar_new (void)
 {
 	GtkWidget *icon_bar;
 
-	icon_bar = GTK_WIDGET (gtk_type_new (e_icon_bar_get_type ()));
+	icon_bar = GTK_WIDGET (g_object_new (E_ICON_BAR_TYPE, NULL));
 
 	return icon_bar;
 }
 
 
 static void
-e_icon_bar_destroy (GtkObject *object)
+e_icon_bar_dispose (GObject *object)
 {
 	EIconBar *icon_bar;
 	int item_num;
@@ -322,7 +302,7 @@ e_icon_bar_destroy (GtkObject *object)
 		icon_bar->auto_scroll_timeout_id = 0;
 	}
 
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 
@@ -330,7 +310,7 @@ static void
 e_icon_bar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
 	EIconBar *icon_bar;
-	gint canvas_width, canvas_height, height;
+	gint canvas_width, canvas_height, height, val;
 
 	icon_bar = E_ICON_BAR (widget);
 
@@ -343,17 +323,22 @@ e_icon_bar_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 	   the canvas, and reset the button labels, so they fit. */
 	e_icon_bar_recalc_common_positions (icon_bar);
 	height = e_icon_bar_recalc_item_positions (icon_bar);
+	val = GTK_LAYOUT (widget)->vadjustment->value;
 
 	gnome_canvas_set_scroll_region (GNOME_CANVAS (widget),
 					0, 0, canvas_width,
 					MAX (height, canvas_height - 1));
 
+	GTK_LAYOUT (widget)->vadjustment->value = val;
 	/* If we are editing an item, make sure it is visible. */
 	e_icon_bar_ensure_edited_item_visible (icon_bar);
 
 	GTK_LAYOUT (widget)->vadjustment->step_increment = 16;
 	if (icon_bar->vadjustment_value_changed_id == 0)
-		icon_bar->vadjustment_value_changed_id = gtk_signal_connect (GTK_OBJECT (GTK_LAYOUT (widget)->vadjustment), "value_changed", GTK_SIGNAL_FUNC (e_icon_bar_vadjustment_value_changed), icon_bar);
+		icon_bar->vadjustment_value_changed_id = g_signal_connect (GTK_LAYOUT (widget)->vadjustment,
+									   "value_changed",
+									   G_CALLBACK (e_icon_bar_vadjustment_value_changed),
+									   icon_bar);
 
 	e_icon_bar_update_highlight (icon_bar);
 }
@@ -401,8 +386,16 @@ e_icon_bar_recalc_item_positions (EIconBar *icon_bar)
 	GtkJustification justify;
 	GtkAnchorType anchor;
 	gint max_lines;
-	GdkFont *font;
 	gboolean line_wrap;
+	PangoContext *context = gtk_widget_get_pango_context (GTK_WIDGET (icon_bar));
+	PangoFontMetrics *metrics;
+
+	metrics = pango_context_get_metrics (context, gtk_widget_get_style (GTK_WIDGET (icon_bar))->font_desc, pango_context_get_language (context));
+
+	text_h = PANGO_PIXELS (pango_font_metrics_get_ascent (metrics)
+			       + pango_font_metrics_get_descent (metrics));
+
+	pango_font_metrics_unref (metrics);
 
 	if (icon_bar->view_type == E_ICON_BAR_LARGE_ICONS) {
 		justify = GTK_JUSTIFY_CENTER;
@@ -410,15 +403,11 @@ e_icon_bar_recalc_item_positions (EIconBar *icon_bar)
 		max_lines = 2;
 		text_x = icon_bar->text_x + (icon_bar->text_w / 2);
 		line_wrap = TRUE;
-		font = gtk_style_get_font (GTK_WIDGET (icon_bar)->style);
-		text_h = font->ascent + font->descent;
 	} else {
 		justify = GTK_JUSTIFY_LEFT;
 		anchor = GTK_ANCHOR_NW;
 		max_lines = 1;
 		text_x = icon_bar->text_x;
-		font = gtk_style_get_font (GTK_WIDGET (icon_bar)->style);
-		text_h = font->ascent + font->descent;
 		line_wrap = FALSE;
 	}
 
@@ -474,7 +463,6 @@ e_icon_bar_recalc_item_positions (EIconBar *icon_bar)
 	return y;
 }
 
-
 static gint
 e_icon_bar_leave_notify_event (GtkWidget *widget, GdkEventCrossing *event)
 {
@@ -593,13 +581,12 @@ e_icon_bar_style_set (GtkWidget *widget, GtkStyle *previous_style) {
 				       EIconBarItem, item_num);
 
 		flattened = flatten_alpha (item->pixbuf,
-					   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
+					   rgb_from_gdk_color (&style->bg [GTK_STATE_ACTIVE]));
 
 		gnome_canvas_item_set (item->image, 				      
 				       "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : item->pixbuf,
 				       NULL);
 		gnome_canvas_item_set (item->text,
-				       "font_gdk", gtk_style_get_font (style),
 				       "fill_color_gdk", &style->fg [GTK_STATE_NORMAL],
 				       NULL);
 
@@ -608,11 +595,10 @@ e_icon_bar_style_set (GtkWidget *widget, GtkStyle *previous_style) {
 			gdk_pixbuf_unref (flattened);
 
 	}
-	
+
 	e_icon_bar_recalc_item_positions (icon_bar);
 }
 
-
 /**
  * e_icon_bar_add_item:
  * @icon_bar: An #EIconBar.
@@ -633,9 +619,10 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 	GtkAnchorType anchor;
 	gint max_lines, retval;
 	GtkStyle *style;
-	GdkFont *font;
 	gdouble text_x, clip_height;
 	GdkPixbuf *flattened = NULL;
+	PangoContext *context;
+	PangoFontMetrics *metrics;
 
 	g_return_val_if_fail (E_IS_ICON_BAR (icon_bar), -1);
 	g_return_val_if_fail (text != NULL, -1);
@@ -656,11 +643,16 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 
 	gtk_widget_ensure_style (GTK_WIDGET (icon_bar));
 	style = GTK_WIDGET (icon_bar)->style;
-	font = gtk_style_get_font (style);
-	clip_height = max_lines * (font->ascent + font->descent);
+	
+	context = gtk_widget_get_pango_context (GTK_WIDGET (icon_bar));
+
+	metrics = pango_context_get_metrics (context, gtk_widget_get_style (GTK_WIDGET (icon_bar))->font_desc, pango_context_get_language (context));
+	clip_height = max_lines * PANGO_PIXELS (pango_font_metrics_get_ascent (metrics)
+						+ pango_font_metrics_get_descent (metrics));
+	pango_font_metrics_unref (metrics);
+
 	item.text = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (icon_bar)->root),
 					   e_text_get_type (),
-					   "font_gdk", font,
 					   "fill_color_gdk", &style->fg [GTK_STATE_NORMAL],
 					   "use_ellipsis", TRUE,
 					   "anchor", anchor,
@@ -670,6 +662,7 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 					   "max_lines", max_lines,
 					   "clip", TRUE,
 					   "clip_width", (gdouble) (icon_bar->text_w),
+					   "width", (gdouble) (icon_bar->text_w),
 					   "clip_height", clip_height,
 					   "text", text,
 					   "draw_background", FALSE,
@@ -678,16 +671,16 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 	e_canvas_item_move_absolute(item.text,
 				    text_x, 0);
 
-	gtk_signal_connect (GTK_OBJECT (item.text), "event",
-			    GTK_SIGNAL_FUNC (e_icon_bar_on_item_event),
-			    icon_bar);
+	g_signal_connect (item.text, "event",
+			  G_CALLBACK (e_icon_bar_on_item_event),
+			  icon_bar);
 
 	item.pixbuf = image;
 	if (image)
-	gdk_pixbuf_ref (image);
+		gdk_pixbuf_ref (image);
 
 	flattened = flatten_alpha (image,
-				   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
+				   rgb_from_gdk_color (&style->bg [GTK_STATE_ACTIVE]));
 	
 	item.image = gnome_canvas_item_new (GNOME_CANVAS_GROUP (GNOME_CANVAS (icon_bar)->root),
 					    gnome_canvas_pixbuf_get_type (),
@@ -701,9 +694,9 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 		/* the canvas item holds the reference now */
 		gdk_pixbuf_unref (flattened);
 
-	gtk_signal_connect (GTK_OBJECT (item.image), "event",
-			    GTK_SIGNAL_FUNC (e_icon_bar_on_item_event),
-			    icon_bar);
+	g_signal_connect (item.image, "event",
+			  G_CALLBACK (e_icon_bar_on_item_event),
+			  icon_bar);
 
 	item.data = NULL;
 	item.destroy = NULL;
@@ -725,7 +718,6 @@ e_icon_bar_add_item (EIconBar	    *icon_bar,
 	return retval;
 }
 
-
 /**
  * e_icon_bar_reorder_item:
  * @icon_bar: An #EIconBar.
@@ -813,9 +805,9 @@ e_icon_bar_get_item_image	(EIconBar	  *icon_bar,
 	g_return_val_if_fail (item_num < icon_bar->items->len, NULL);
 
 	item = &g_array_index (icon_bar->items, EIconBarItem, item_num);
-	gtk_object_get (GTK_OBJECT (item->image),
-			"GnomeCanvasPixbuf::pixbuf", &image,
-			NULL);
+	g_object_get (item->image,
+		      "GnomeCanvasPixbuf::pixbuf", &image,
+		      NULL);
 	return image;
 }
 
@@ -844,7 +836,7 @@ e_icon_bar_set_item_image	(EIconBar	  *icon_bar,
 	item = &g_array_index (icon_bar->items, EIconBarItem, item_num);
 
 	flattened = flatten_alpha (item->pixbuf,
-				   rgb_from_gdk_color (&style->bg [GTK_STATE_NORMAL]));
+				   rgb_from_gdk_color (&style->bg [GTK_STATE_ACTIVE]));
 
 	gnome_canvas_item_set (item->image,
 			       "GnomeCanvasPixbuf::pixbuf", flattened ? flattened : image,
@@ -876,9 +868,9 @@ e_icon_bar_get_item_text	(EIconBar	  *icon_bar,
 	g_return_val_if_fail (item_num < icon_bar->items->len, NULL);
 
 	item = &g_array_index (icon_bar->items, EIconBarItem, item_num);
-	gtk_object_get (GTK_OBJECT (item->text),
-			"EText::text", &text,
-			NULL);
+	g_object_get (item->text,
+		      "EText::text", &text,
+		      NULL);
 
 	return text;
 }
@@ -1035,8 +1027,8 @@ e_icon_bar_on_item_event (GnomeCanvasItem *item,
 		if (icon_bar->editing_item_num == -1
 		    || icon_bar->editing_item_num != item_num) {
 			e_icon_bar_item_pressed (icon_bar, item_num, event);
-			gtk_signal_emit_stop_by_name (GTK_OBJECT (item),
-						      "event");
+			g_signal_stop_emission_by_name (item,
+							"event");
 			return TRUE;
 		}
 		break;
@@ -1050,8 +1042,8 @@ e_icon_bar_on_item_event (GnomeCanvasItem *item,
 		if (icon_bar->editing_item_num == -1
 		    || icon_bar->editing_item_num != item_num) {
 			e_icon_bar_item_released (icon_bar, item_num, event);
-			gtk_signal_emit_stop_by_name (GTK_OBJECT (item),
-						      "event");
+			g_signal_stop_emission_by_name (item,
+							"event");
 			return TRUE;
 		}
 		break;
@@ -1110,9 +1102,9 @@ e_icon_bar_item_pressed (EIconBar *icon_bar,
 				  GDK_BUTTON1_MOTION_MASK,
 				  NULL, NULL, event->button.time);
 	} else if (button == 3) {
-		gtk_signal_emit (GTK_OBJECT (icon_bar),
-				 e_icon_bar_signals[ITEM_SELECTED],
-				 event, item_num);
+		g_signal_emit (icon_bar,
+			       e_icon_bar_signals[ITEM_SELECTED], 0,
+			       event, item_num);
 	}
 }
 
@@ -1135,9 +1127,9 @@ e_icon_bar_item_released (EIconBar *icon_bar,
 
 		if (icon_bar->pressed_item_num != -1
 		    && icon_bar->pressed_item_num == icon_bar->mouse_over_item_num) {
-			gtk_signal_emit (GTK_OBJECT (icon_bar),
-					 e_icon_bar_signals[ITEM_SELECTED],
-					 event, item_num);
+			g_signal_emit (icon_bar,
+				       e_icon_bar_signals[ITEM_SELECTED], 0,
+				       event, item_num);
 		}
 
 		icon_bar->pressed_item_num = -1;
@@ -1166,9 +1158,9 @@ e_icon_bar_item_motion (EIconBar *icon_bar,
 			   a pointer grab. */
 			gdk_pointer_ungrab (event->motion.time);
 
-			gtk_signal_emit (GTK_OBJECT (icon_bar),
-					 e_icon_bar_signals[ITEM_DRAGGED],
-					 event, icon_bar->dragged_item_num);
+			g_signal_emit (icon_bar,
+				       e_icon_bar_signals[ITEM_DRAGGED], 0,
+				       event, icon_bar->dragged_item_num);
 			
 			/* Don't show the button as pressed while dragging. */
 			icon_bar->pressed_item_num = -1;
@@ -1565,6 +1557,7 @@ e_icon_bar_drag_motion (GtkWidget      *widget,
 						     x + scroll_x,
 						     y + scroll_y,
 						     &before_item);
+
 	e_icon_bar_item_motion (icon_bar, item_num, NULL);
 	e_icon_bar_set_dragging_before_item (icon_bar, before_item);
 
@@ -1581,7 +1574,8 @@ e_icon_bar_drag_motion (GtkWidget      *widget,
 			gtk_timeout_remove (icon_bar->auto_scroll_timeout_id);
 			icon_bar->auto_scroll_timeout_id = 0;
 		}
-		return TRUE;
+		gdk_drag_status(context, GDK_ACTION_MOVE, time);
+		return FALSE;
 	}
 
 	if (icon_bar->auto_scroll_timeout_id == 0) {
@@ -1589,7 +1583,8 @@ e_icon_bar_drag_motion (GtkWidget      *widget,
 		icon_bar->auto_scroll_delay = E_ICON_BAR_SCROLL_DELAY;
 	}
 
-	return TRUE;
+	gdk_drag_status(context, GDK_ACTION_MOVE, time);
+	return FALSE;
 }
 
 
