@@ -41,8 +41,8 @@ static GtkObjectClass *parent_class;
 
 /* The arguments we take */
 enum {
-	ARG_0,
-	ARG_ECML
+	PROP_0,
+	PROP_ECML
 };
 
 static void
@@ -50,23 +50,14 @@ ecmlc_ecml_changed (ECategoriesMasterList *ecml, ECategoriesMasterListCombo *ecm
 {
 	int count = e_categories_master_list_count (ecml);
 	int i;
-	GList *strings = NULL, *iter;
+	GList *strings = NULL;
 
 	for (i = 0; i < count; i++) {
 		strings = g_list_prepend (strings, (gpointer) e_categories_master_list_nth (ecml, i));
 	}
 	strings = g_list_sort (strings, (GCompareFunc) g_utf8_collate);
-
-	/* Walk through the list and convert utf8 strings to locale */
-	for (iter = strings; iter != NULL; iter = g_list_next (iter)) {
-		/* We don't own the strings returned by e_categories_master_list_nth, so we
-		   don't need to free them. */
-		iter->data = e_utf8_to_gtk_string (GTK_WIDGET (ecmlc), (gchar *) iter->data);
-	}
-
-	strings = g_list_prepend (strings, g_strdup (""));
+	strings = g_list_prepend (strings, "");
 	gtk_combo_set_popdown_strings (GTK_COMBO (ecmlc), strings);
-	g_list_foreach (strings, (GFunc) g_free, NULL);
 	g_list_free (strings);
 }
 
@@ -79,10 +70,10 @@ ecmlc_add_ecml (ECategoriesMasterListCombo *ecmlc,
 
 	ecmlc->priv->ecml = ecml;
 	if (ecml) {
-		gtk_object_ref (GTK_OBJECT (ecml));
+		g_object_ref (ecml);
 		ecmlc->priv->ecml_changed_signal_id =
-			gtk_signal_connect (GTK_OBJECT (ecml), "changed",
-					    GTK_SIGNAL_FUNC (ecmlc_ecml_changed), ecmlc);
+			g_signal_connect (ecml, "changed",
+					  G_CALLBACK (ecmlc_ecml_changed), ecmlc);
 		ecmlc_ecml_changed (ecml, ecmlc);
 	}
 }
@@ -92,16 +83,16 @@ ecmlc_remove_ecml (ECategoriesMasterListCombo *ecmlc)
 {
 	if (ecmlc->priv->ecml) {
 		if (ecmlc->priv->ecml_changed_signal_id)
-			gtk_signal_disconnect (GTK_OBJECT (ecmlc->priv->ecml),
-					       ecmlc->priv->ecml_changed_signal_id);
-		gtk_object_unref (GTK_OBJECT (ecmlc->priv->ecml));
+			g_signal_handler_disconnect (ecmlc->priv->ecml,
+						     ecmlc->priv->ecml_changed_signal_id);
+		g_object_unref (ecmlc->priv->ecml);
 	}
 	ecmlc->priv->ecml = NULL;
 	ecmlc->priv->ecml_changed_signal_id = 0;
 }
 
 static void
-ecmlc_destroy (GtkObject *object)
+ecmlc_dispose (GObject *object)
 {
 	ECategoriesMasterListCombo *ecmlc = E_CATEGORIES_MASTER_LIST_COMBO (object);
 
@@ -111,53 +102,57 @@ ecmlc_destroy (GtkObject *object)
 		ecmlc->priv = NULL;
 	}
 	
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
+	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
 static void
-ecmlc_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
+ecmlc_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
 	ECategoriesMasterListCombo *ecmlc;
 
-	ecmlc = E_CATEGORIES_MASTER_LIST_COMBO (o);
+	ecmlc = E_CATEGORIES_MASTER_LIST_COMBO (object);
 	
-	switch (arg_id){
-	case ARG_ECML:
+	switch (prop_id){
+	case PROP_ECML:
 		ecmlc_remove_ecml (ecmlc);
-		ecmlc_add_ecml (ecmlc, (ECategoriesMasterList *) GTK_VALUE_OBJECT (*arg));
+		ecmlc_add_ecml (ecmlc, (ECategoriesMasterList *) g_value_get_object (value));
 		break;
 	}
 }
 
 static void
-ecmlc_get_arg (GtkObject *o, GtkArg *arg, guint arg_id)
+ecmlc_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
 	ECategoriesMasterListCombo *ecmlc;
 
-	ecmlc = E_CATEGORIES_MASTER_LIST_COMBO (o);
+	ecmlc = E_CATEGORIES_MASTER_LIST_COMBO (object);
 
-	switch (arg_id) {
-	case ARG_ECML:
-		GTK_VALUE_OBJECT (*arg) = (GtkObject *) ecmlc->priv->ecml;
+	switch (prop_id) {
+	case PROP_ECML:
+		g_value_set_object (value, ecmlc->priv->ecml);
 		break;
 
 	default:
-		arg->type = GTK_TYPE_INVALID;
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
 	}
 }
 
 static void
-ecmlc_class_init (GtkObjectClass *object_class)
+ecmlc_class_init (GObjectClass *object_class)
 {
-	parent_class   = gtk_type_class (PARENT_TYPE);
+	parent_class   = g_type_class_ref (PARENT_TYPE);
 
-	object_class->destroy = ecmlc_destroy;
-	object_class->set_arg = ecmlc_set_arg;
-	object_class->get_arg = ecmlc_get_arg;
+	object_class->dispose = ecmlc_dispose;
+	object_class->set_property = ecmlc_set_property;
+	object_class->get_property = ecmlc_get_property;
 
-	gtk_object_add_arg_type ("ECategoriesMasterListCombo::ecml", E_CATEGORIES_MASTER_LIST_TYPE,
-				 GTK_ARG_READWRITE, ARG_ECML);
+	g_object_class_install_property (object_class, PROP_ECML,
+					 g_param_spec_object ("ecml",
+							      _( "ECML" ),
+							      _( "ECategoriesMasterListCombo" ),
+							      E_CATEGORIES_MASTER_LIST_TYPE,
+							      G_PARAM_READWRITE));
 }
 
 static void
@@ -185,9 +180,9 @@ e_categories_master_list_combo_construct (ECategoriesMasterListCombo *ecmlc,
 	g_return_val_if_fail (ecmlc != NULL, NULL);
 	g_return_val_if_fail (ecml != NULL, NULL);
 
-	gtk_object_set (GTK_OBJECT (ecmlc),
-			"ecml", ecml,
-			NULL);
+	g_object_set (ecmlc,
+		      "ecml", ecml,
+		      NULL);
 
 	return GTK_WIDGET (ecmlc);
 }
@@ -202,7 +197,7 @@ e_categories_master_list_combo_construct (ECategoriesMasterListCombo *ecmlc,
 GtkWidget *
 e_categories_master_list_combo_new (ECategoriesMasterList *ecml)
 {
-	ECategoriesMasterListCombo *ecmlc = gtk_type_new (E_CATEGORIES_MASTER_LIST_COMBO_TYPE);
+	ECategoriesMasterListCombo *ecmlc = g_object_new (E_CATEGORIES_MASTER_LIST_COMBO_TYPE, NULL);
 
 	if (e_categories_master_list_combo_construct (ecmlc, ecml) == NULL){
 		gtk_object_destroy (GTK_OBJECT (ecmlc));
