@@ -370,9 +370,7 @@ item_removed (EReflowModel *model, int i, EReflow *reflow)
 static void
 items_inserted (EReflowModel *model, int position, int count, EReflow *reflow)
 {
-	int i, c;
-	int oldcount;
-	int lowest_column;
+	int i, oldcount;
 
 	if (position < 0 || position > reflow->count)
 		return;
@@ -494,7 +492,6 @@ set_empty(EReflow *reflow)
 							      "width", reflow->minimum_width,
 							      "clip", TRUE,
 							      "use_ellipsis", TRUE,
-							      "fill_color", "black",
 							      "justification", GTK_JUSTIFY_CENTER,
 							      "text", reflow->empty_message,
 							      "draw_background", FALSE,
